@@ -90,15 +90,19 @@ class _TestDatabase(object):
             db.add(f)
         assert writer.count() == 1
 
-        with writer.transaction() as db:
-            db.add(j)
-            raise Exception("boo!")
-        assert writer.count() == 1
+        try:
+            with writer.transaction() as db:
+                db.add(j)
+                raise Exception("boo!")
+        except:
+            assert writer.count() == 1
 
-        with writer.transaction() as db:
-            del db['XX:9']
-            raise Exception("boo!")
-        assert writer.count() == 1
+        try:
+            with writer.transaction() as db:
+                del db['XX:9']
+                raise Exception("boo!")
+        except:
+            assert writer.count() == 1
 
         with writer.transaction() as db:
             del db['XX:9']
